# Menu Migration

The Menu Migration module helps developers to import and export menu items
from one Drupal copy to another one. This was built quickly for a specific
project setup, so the options are limited, but it can be extended in the
future.

The functionality imports and exports one or more menu items per subsite,
so it works with multisite, but most probably it doesn't work with
multilingual, and it only manages MenuLinkContent items.

For a full description of the module, visit the
[project page](https://www.drupal.org/project/menu_migration).

Submit bug reports and feature suggestions, or track changes in the
[issue queue](https://www.drupal.org/project/issues/menu_migration).


## Table of contents

- Requirements
- Installation
- Configuration
- Drush integration
- Troubleshooting
- Maintainers


## Requirements

The menu structure is removed before import, so any Views menu items will lose
the parent upon import. The workaround is to **not** define menu items in
Views, but only add them via the menu, for example "Main navigation" under
`/admin/structure/menu/manage/main`. See
[Support menu items via Views](https://www.drupal.org/project/menu_migration/issues/3407891).

File permissions actions might be required on the server.

## Installation

Install as you would normally install a contributed Drupal module. For further
information, see
[Installing Drupal Modules](https://www.drupal.org/docs/extending-drupal/installing-drupal-modules).


## Configuration

The menu items are exported in JSON-format in a folder on the server, defined
in the configuration form provided by the module.


### Defining export folder

1. Navigate to Configuration → Development → Menu Migration → Settings
1. By default, the export folder is set to `../config/menu_migration`,
   but you can change it to any directory relative to `DRUPAL_ROOT`
1. When you save this form, you might get an error about permissions, so please
   make sure that the selected folder has write access for either apache user
   (if you plan to use the interface) or the shell user (if you plan to use
   drush), or both

### Export menu
1. Navigate to Configuration → Development → Menu Migration → Export
1. Select one or more menus and click on export
1. The items are exported as json in:
   `<export_folder>/sites/<site_name>/<menu_name>/<menu_name>.json`

### Import menu

1. To import, navigate to Configuration → Development → Import
1. Select one or more menus and click on import
1. When importing, all MenuLinkContent items that exist in the target menu(s)
   will be deleted prior to import


## Drush integration

Menu migration provides two Drush commands for managing imports and exports.
You can import one or more menus at a time. If you want to import more than
one, the menu names need to be separated by commas.

Examples:
```shell
# Export "main" menu.
drush menu_migration:export main
# Export "main", "footer" menus
drush menu_migration:export main,footer
# Alias for export "main" menu.
drush mme main

# Import "main" menu.
drush menu_migration:import main
# Import "main", "footer" menus
drush menu_migration:import main,footer
# Alias for import "main" menu.
drush mmi main
```


## Troubleshooting

If you're getting errors that the menus can't be exported, please make
sure that the target directory has writing access by the server user that
is about to execute the exports.

If the menu item hierarchy is messed up after import, make sure menu items are
only added via the menu (for example "Main navigation") and not a View.


## Maintainers

Cristina B. - [bbu23](https://www.drupal.org/u/bbu23)